@@ -1,6 +1,9 @@
 /*
+ * part of owftpd By Paul H Alfille
+ * The whole is GPLv2 licenced though the ftp code was more liberally licenced when first used.
+ */
 
-$Id$
+/*
  
 This is the code that waits for client connections and creates the
 threads that handle them.  When ftp_listener_init() is called, it binds
@@ -52,13 +55,17 @@ int ftp_listener_init(struct ftp_listener_s *f)
 
 	daemon_assert(f != NULL);
 
+	if ( Outbound_Control.head->name == NULL ) {
+		Outbound_Control.head->name = owstrdup( DEFAULT_FTP_PORT ) ;
+	}
+	
 	LEVEL_DEBUG("ftp_listener_init: name=[%s]", Outbound_Control.head->name);
 	
 	// For sone reason, there must be an IP address included
 	if (strchr(Outbound_Control.head->name, ':') == NULL) {
 		char *newname;
 		char *oldname = Outbound_Control.head->name;
-		newname = malloc(8 + strlen(oldname) + 1); // "0.0.0.0:" + null-char.
+		newname = owmalloc(8 + strlen(oldname) + 1); // "0.0.0.0:" + null-char.
 		if (newname == NULL) {
 			LEVEL_DEFAULT("Cannot allocate menory for port name");
 			return 0;
@@ -67,7 +74,7 @@ int ftp_listener_init(struct ftp_listener_s *f)
 		strcat(newname, oldname);
 		//LEVEL_DEBUG("OWSERVER composite name <%s> -> <%s>\n",oldname,newname);
 		Outbound_Control.head->name = newname;
-		free(oldname);
+		owfree(oldname);
 	}
 
 	if ( BAD( ServerOutSetup(Outbound_Control.head) ) ) {
@@ -148,7 +155,7 @@ static int invariant(const struct ftp_listener_s *f)
 	if (f == NULL) {
 		return 0;
 	}
-	if (f->file_descriptor < 0) {
+	if (FILE_DESCRIPTOR_NOT_VALID(f->file_descriptor)) {
 		return 0;
 	}
 	if (f->max_connections <= 0) {
@@ -162,10 +169,10 @@ static int invariant(const struct ftp_listener_s *f)
 	if ((dir_len <= 0) || (dir_len > PATH_MAX)) {
 		return 0;
 	}
-	if (f->shutdown_request_fd[fd_pipe_write] < 0) {
+	if (FILE_DESCRIPTOR_NOT_VALID(f->shutdown_request_fd[fd_pipe_write])) {
 		return 0;
 	}
-	if (f->shutdown_request_fd[fd_pipe_read] < 0) {
+	if (FILE_DESCRIPTOR_NOT_VALID(f->shutdown_request_fd[fd_pipe_read])) {
 		return 0;
 	}
 	return 1;
@@ -178,7 +185,7 @@ static void *connection_acceptor(void *v)
 	struct ftp_listener_s *f = (struct ftp_listener_s *) v;
 	int num_error;
 
-	int file_descriptor;
+	FILE_DESCRIPTOR_OR_ERROR file_descriptor;
 	int tcp_nodelay;
 	sockaddr_storage_t client_addr;
 	sockaddr_storage_t server_addr;
@@ -208,7 +215,7 @@ static void *connection_acceptor(void *v)
 
 		/* if data arrived on our pipe, we've been asked to exit */
 		if (FD_ISSET(f->shutdown_request_fd[fd_pipe_read], &readfds)) {
-			close(f->file_descriptor);
+			Test_and_Close( & f->file_descriptor);
 			LEVEL_CONNECT("Listener no longer accepting connections");
 			pthread_exit(NULL);
 			return VOID_RETURN;
@@ -217,26 +224,25 @@ static void *connection_acceptor(void *v)
 		/* otherwise accept our pending connection (if any) */
 		addr_len = sizeof(sockaddr_storage_t);
 		file_descriptor = accept(f->file_descriptor, (struct sockaddr *) &client_addr, &addr_len);
-		if (file_descriptor >= 0) {
+		if (FILE_DESCRIPTOR_VALID(file_descriptor)) {
 			tcp_nodelay = 1;
 			if (setsockopt(file_descriptor, IPPROTO_TCP, TCP_NODELAY, (void *) &tcp_nodelay, sizeof(int)) != 0) {
 				ERROR_CONNECT("Error in setsockopt(), FTP server dropping connection");
-				close(file_descriptor);
+				Test_and_Close( & file_descriptor);
 				continue;
 			}
 
 			addr_len = sizeof(sockaddr_storage_t);
 			if (getsockname(file_descriptor, (struct sockaddr *) &server_addr, &addr_len) == -1) {
 				ERROR_CONNECT("Error in getsockname(), FTP server dropping connection");
-				close(file_descriptor);
+				Test_and_Close( & file_descriptor);
 				continue;
 			}
 
-			info = (struct connection_info_s *)
-				malloc(sizeof(struct connection_info_s));
+			info = (struct connection_info_s *) owmalloc(sizeof(struct connection_info_s));
 			if (info == NULL) {
 				LEVEL_CONNECT("Out of memory, FTP server dropping connection");
-				close(file_descriptor);
+				Test_and_Close( & file_descriptor);
 				continue;
 			}
 			info->ftp_listener = f;
@@ -247,7 +253,7 @@ static void *connection_acceptor(void *v)
 				LEVEL_CONNECT("Eerror initializing FTP session, FTP server exiting");
 				close(file_descriptor);
 				telnet_session_destroy(&info->telnet_session);
-				free(info);
+				owfree(info);
 				continue;
 			}
 
@@ -259,7 +265,7 @@ static void *connection_acceptor(void *v)
 				ERROR_CONNECT("Error creating new thread");
 				close(file_descriptor);
 				telnet_session_destroy(&info->telnet_session);
-				free(info);
+				owfree(info);
 			}
 
 			num_error = 0;
@@ -383,7 +389,7 @@ static void connection_handler_cleanup(void *v)
 	ftp_session_destroy(&info->ftp_session);
 	telnet_session_destroy(&info->telnet_session);
 
-	free(info);
+	owfree(info);
 }
 
 void ftp_listener_stop(struct ftp_listener_s *f)
