@@ -1,5 +1,4 @@
 /*
-$Id$
     OW -- One-Wire filesystem
     version 0.4 7/2/2003
 
@@ -55,24 +54,12 @@ $Id$
 #define OW_USB_CYCLE_H
 
 #if OW_USB
-#include <sys/types.h> // Mac needs this before <usb.h> according to Peter Peter Radcliffe's work
-#include <usb.h>
 
 /* All the rest of the code sees is the DS9490_detect routine and the iroutine structure */
 
-struct usb_list {
-	struct usb_bus *bus;
-	struct usb_device *dev;
-	int usb_bus_number;
-	int usb_dev_number;
-};
-
-void USB_first(struct usb_list *ul);
-GOOD_OR_BAD USB_next(struct usb_list *ul);
-GOOD_OR_BAD USB_next_until_n(struct usb_list *ul, int num) ;
+GOOD_OR_BAD USB_match(libusb_device * dev);
 GOOD_OR_BAD DS9490_root_dir( struct dirblob * db, struct connection_in * in ) ;
 GOOD_OR_BAD DS9490_ID_this_master(struct connection_in *in);
-char *DS9490_device_name(const struct usb_list *ul);
 
 #define DS2490_USB_VENDOR  0x04FA
 #define DS2490_USB_PRODUCT 0x2490
