@@ -1,5 +1,5 @@
 /*
-$Id: dir.c,v 1.27 2012/03/27 03:42:48 alfille Exp $
+$Id$
     OW_HTML -- OWFS used for the web
     OW -- One-Wire filesystem
 
@@ -18,7 +18,7 @@ $Id: dir.c,v 1.27 2012/03/27 03:42:48 alfille Exp $
  *
  *   You should have received a copy of the GNU General Public License
  *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 /* owserver -- responds to requests over a network socket, and processes them on the 1-wire bus/
@@ -52,7 +52,7 @@ struct dirhandlerstruct {
 static void DirHandlerCallback(void *v, const struct parsedname *pn_entry)
 {
 	struct dirhandlerstruct *dhs = (struct dirhandlerstruct *) v;
-	char *path = pn_entry->path;
+	const char *path = pn_entry->path;
 
 	LEVEL_DEBUG("owserver Calling dir=%s", SAFESTRING(path));
 
